@@ -1,9 +1,9 @@
-from alpaca.common.models.trading import Order as BaseOrder
+from alpaca.trading.models import Order as BaseOrder
 
 
 class Order(BaseOrder):
     """
-    See common Order model for full list of base attributes.
+    See base alpaca.trading.models.Order model for full list of base attributes.
 
     Attributes:
         commission (float): The dollar value commission you want to charge the end user.
